@@ -28,7 +28,7 @@ from ..utils.autoai.utils import (prepare_auto_ai_model_to_publish, prepare_auto
                                   remove_file, prepare_auto_ai_model_to_publish_notebook,
                                   prepare_auto_ai_model_to_publish_notebook_normal_scenario,
                                   download_wml_pipeline_details_from_file, get_sw_spec_and_type_based_on_sklearn,
-                                  check_if_ts_pipeline_is_winner)
+                                  check_if_ts_pipeline_is_winner, convert_dataframe_to_fields_values_payload)
 from ..utils.deployment.errors import (WrongDeploymnetType, ModelTypeNotSupported, NotAutoAIExperiment,
                                        DeploymentNotSupported, MissingSpace, ModelPromotionFailed,
                                        ServingNameNotAvailable)
@@ -474,32 +474,36 @@ class BaseDeployment(ABC):
         payload: pandas.DataFrame, required
             DataFrame with data to test the model.
         """
-        import pandas as pd
 
         if isinstance(kwargs['payload'], DataFrame):
-            fields = kwargs['payload'].columns.tolist()
-            data = kwargs['payload'].where(pd.notnull(kwargs['payload']), None)
-            values = data.values
+            payload = convert_dataframe_to_fields_values_payload(kwargs['payload'])
+            input_data = [payload]
 
-            # note: scoring endpoint could not recognize NaN values, convert NaN to None
-            try:
-                values[pd.isnull(values)] = None
+        elif isinstance(kwargs['payload'], dict):
+            observations_df = kwargs['payload'].get('observations', DataFrame())
+            supporting_features_df = kwargs['payload'].get('supporting_features')
 
-            # note: above code fails when there is no null values in a dataframe
-            except TypeError:
-                pass
-            # --- end note
+            if isinstance(observations_df, DataFrame) and \
+                    (isinstance(supporting_features_df, DataFrame) or supporting_features_df is None):
+                observations_payload = convert_dataframe_to_fields_values_payload(observations_df)
+                observations_payload['id'] = 'observations'
+                input_data = [observations_payload]
 
-            values = values.tolist()
-            # --- end note
+                if supporting_features_df is not None:
+                    supporting_features_payload = convert_dataframe_to_fields_values_payload(supporting_features_df)
+                    supporting_features_payload['id'] = 'supporting_features'
+                    input_data.append(supporting_features_payload)
+            else:
+                raise TypeError('Missing data observations in payload or observations'
+                                 'or supporting_features are not pandas DataFrames.')
 
-            payload = {'fields': fields, 'values': values}
         else:
-            raise TypeError('X should be of type pandas.DataFrame.')
+            raise TypeError(f"Scoring payload has invalid type: {type(kwargs['payload'])}. "
+                            f"Supported types are: pandas.DataFrame and dictionary.")
 
         transaction_id = kwargs.get('transaction_id')
 
-        scoring_payload = {self._target_workspace.wml_client.deployments.ScoringMetaNames.INPUT_DATA: [payload]}
+        scoring_payload = {self._target_workspace.wml_client.deployments.ScoringMetaNames.INPUT_DATA: input_data}
 
         score = self._target_workspace.wml_client.deployments.score(self.id, scoring_payload, transaction_id=transaction_id)
 
