@@ -698,9 +698,17 @@ class Deployments(WMLResource):
                 scoring_values = each_score_request["values"]
                 # Check feature types, currently supporting pandas df, numpy.ndarray, python lists and Dmatrix
                 if (isinstance(scoring_values, pd.DataFrame)):
+                    scoring_values = scoring_values.where(pd.notnull(scoring_values), None)
                     fields_names = scoring_values.columns.values.tolist()
                     values = scoring_values.values.tolist()
 
+                    try:
+                        values[pd.isnull(values)] = None
+
+                        # note: above code fails when there is no null values in a dataframe
+                    except TypeError:
+                        pass
+
                     each_score_request["values"] = values
                     if fields_names is not None:
                         each_score_request["fields"] = fields_names
