@@ -175,6 +175,9 @@ class AutoAI(BaseExperiment):
                   lookback_window: int = None,
                   forecast_window: int = None,
                   backtest_gap_length: int = None,
+                  feature_columns: List[str] = None,
+                  pipeline_types: List[ForecastingPipelineTypes] = None,
+                  supporting_features_at_forecast: bool = None,
                   cognito_transform_names: List['Transformers'] = None,
                   data_join_graph: 'DataJoinGraph' = None,
                   csv_separator: Union[List[str], str] = ',',
@@ -266,8 +269,17 @@ class AutoAI(BaseExperiment):
             Used for forecasting prediction type. Configure gap between backtests. Default value: 0
             Value from range [0, data length / 4]
 
+        feature_columns: List[str], optional
+            List of feature columns used for forecasting prediction type. May contain target column and/or supporting feature columns.
+
+        pipeline_types: List[ForecastingPipelineTypes], optional
+            List of pipeline types to be used for forecasting prediction type.
+
+        supporting_features_at_forecast: bool, optional
+            Enables usage of future supporting feature values during forecast.
+
         cognito_transform_names: List['Transformers'], optional
-            List of transformers to include in feature enginnering computation process.
+            List of transformers to include in the feature enginnering computation process.
             See: AutoAI.Transformers
 
         csv_separator: Union[List[str], str], optional
@@ -456,19 +468,6 @@ class AutoAI(BaseExperiment):
         if prediction_type == 'timeseries':
             prediction_type = PredictionType.FORECASTING
 
-        # TS exogenous, to be removed
-        feature_columns = None
-        pipeline_types = None
-        supporting_features_at_forecast = None
-
-        if 'feature_columns' in kwargs:
-            feature_columns = kwargs.pop('feature_columns')
-
-        if 'pipeline_types' in kwargs:
-            pipeline_types = kwargs.pop('pipeline_types')
-
-        if 'supporting_features_at_forecast' in kwargs:
-            supporting_features_at_forecast = kwargs.pop('supporting_features_at_forecast')
 
         if prediction_type != PredictionType.FORECASTING and retrain_on_holdout is None:
             retrain_on_holdout = True
@@ -536,7 +535,7 @@ class AutoAI(BaseExperiment):
             for batched_estimator in include_batched_ensemble_estimators:
                 basic_estimator_str = batched_estimator.value.split("(")[1][:-1]
                 basic_estimator = translate_estimator_string_to_enum(basic_estimator_str)
-                if not include_only_estimators or basic_estimator not in include_only_estimators:
+                if include_only_estimators is not None and basic_estimator not in include_only_estimators:
                     raise MissingEstimatorForExistingBatchedEstimator(batched_estimator, basic_estimator)
 
         validate_optimizer_enum_values(
