@@ -34,7 +34,7 @@ from ibm_watson_machine_learning.utils.autoai.progress_bar import ProgressBar
 from ibm_watson_machine_learning.utils.autoai.utils import (
     fetch_pipelines, is_ipython, ProgressGenerator, check_dependencies_versions, try_import_autoai_libs,
     create_summary, prepare_auto_ai_model_to_publish_normal_scenario, get_sw_spec_and_type_based_on_sklearn,
-    get_values_for_imputation_strategy, try_import_autoai_ts_libs)
+    get_values_for_imputation_strategy, try_import_autoai_ts_libs, _download_notebook)
 from .base_engine import BaseEngine
 from ibm_watson_machine_learning.helpers.connections import DataConnection
 
@@ -415,7 +415,7 @@ class WMLEngine(BaseEngine):
                 self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT]['runtimes'][0]['version'] = (
                 self._auto_pipelines_parameters['autoai_pod_version'])
         # --- end note
-        
+
         # note: OBM part, only if user specified OBM as a preprocess method
         if self._auto_pipelines_parameters['data_join_graph']:
             # note: remove kb params for OBM only training
@@ -487,7 +487,7 @@ class WMLEngine(BaseEngine):
                     template_id = 'spark-3.0.0-automl-cp4d-template'
                 else:
                     template_id = 'spark-2.4.0-automl-icp4d-template'
-                    
+
                 self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
                     'pipelines'][0]['nodes'][0]['parameters']['engine'][
                     'template_id'] = template_id
@@ -880,13 +880,24 @@ class WMLEngine(BaseEngine):
                     pipeline_parameters['features_importance'] = self._get_features_importance(pipeline)
 
                 elif self._auto_pipelines_parameters['prediction_type'] == 'forecasting':
-                    data = self._get_data_from_property_or_file('daub_status', pipeline['context']['timeseries'],
-                                                                     run_params['entity']['results_reference'],
-                                                                     [{}, {}])
-                    if 'visualization' in data:
-                        if 'visualization' not in pipeline_parameters:
-                            pipeline_parameters['visualization'] = {}
-                        pipeline_parameters['visualization'].update(data['visualization'])
+                    phases_to_combine_visualization = ['after_backtest_execution', 'after_holdout_execution']
+                    for pipeline in run_params['entity']['status'].get('metrics', [])[::-1]:
+                        pipeline_phase = pipeline['context'].get('phase')
+                        # note: end earlier if all phases were added to the visualisation
+                        if len(phases_to_combine_visualization) == 0:
+                            break
+                        #end note
+                        if pipeline['context']['intermediate_model']['name'].split('P')[-1] == pipeline_name.split('_')[
+                            -1] and pipeline_phase in phases_to_combine_visualization:
+                            phases_to_combine_visualization.remove(pipeline_phase)
+                            data = self._get_data_from_property_or_file('daub_status', pipeline['context']['timeseries'],
+                                                                             run_params['entity']['results_reference'],
+                                                                             [{}, {}])
+                            if 'visualization' in data:
+                                if 'visualization' not in pipeline_parameters:
+                                    pipeline_parameters['visualization'] = {}
+                                pipeline_parameters['visualization'].update(data['visualization'])
+
 
                 else:
                     raise InvalidPredictionType(self._auto_pipelines_parameters['prediction_type'],
@@ -1074,6 +1085,48 @@ class WMLEngine(BaseEngine):
 
         return pipelines.get(pipeline_name), check_lale
 
+    def get_pipeline_notebook(self, pipeline_name: str, local_path: str = '.', filename: str = None) -> str:
+        """
+        Download specified pipeline notebook from WML.
+
+        Parameters
+        ----------
+        pipeline_name: str, required
+            Pipeline name, if you want to see the pipelines names, please use summary() method.
+
+        local_path: str, optional
+            Working directory path.
+
+        filename: str, optional
+            Filename under which the pipeline notebook will be saved.
+
+        Returns
+        -------
+        Path to saved pipeline notebook.
+        """
+
+        # note: Show warning if OBM
+        if 'auto_ai.obm' in str(self._wml_stored_pipeline_details):
+            warnings.warn("OBM pipeline notebook can be used only for inspection and deployment purposes.", Warning, stacklevel=2)
+        # end note
+
+        run_params = self._wml_client.training.get_details(training_uid=self._current_run_id)
+
+        # note: recreation of s3 creds from connection asset
+        results_reference = DataConnection._from_dict(run_params['entity']['results_reference'])
+        results_reference._wml_client = self._wml_client
+        results_reference._check_if_connection_asset_is_s3()
+        run_params['entity']['results_reference'] = results_reference._to_dict()
+        # --- end note
+
+        return _download_notebook(
+            run_params=run_params,
+            path=local_path,
+            pipeline_name=pipeline_name,
+            wml_client=self._wml_client,
+            filename=filename
+        )
+
     def get_best_pipeline(self, local_path: str = '.', persist: 'bool' = False) -> Tuple['Pipeline', bool]:
         """
         Download best pipeline from WML.
