@@ -11,7 +11,7 @@
 #  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
-
+import json
 import os
 
 from copy import deepcopy
@@ -89,7 +89,7 @@ class RemoteAutoPipelines(BaseAutoPipelines):
         List of estimators to include in computation process.
 
     cognito_transform_names: List['Transformers'], optional
-        List of transformers to include in feature enginnering computation process.
+        List of transformers to include in the feature enginnering computation process.
         See: AutoAI.Transformers
 
     csv_separator: Union[List[str], str], optional
@@ -732,6 +732,84 @@ class RemoteAutoPipelines(BaseAutoPipelines):
             raise ValueError('Incorrect value of \'astype\'. '
                              'Should be either PipelineTypes.SKLEARN or PipelineTypes.LALE')
 
+    def get_pipeline_notebook(self,
+                     pipeline_name: str = None,
+                     filename: str = None,
+                     insert_to_cell: bool = False) -> str:
+        """
+        Download specified pipeline notebook from WML.
+
+        Parameters
+        ----------
+        pipeline_name: str, optional
+            Pipeline name, if you want to see the pipelines names, please use summary() method.
+            If this parameter is None, the best pipeline will be fetched.
+
+        filename: str, optional
+            Filename under which the pipeline notebook will be saved.
+
+        insert_to_cell: bool, optional
+            If run in jupyter notebook, if set inserts the notebook into cell below.
+
+        Returns
+        -------
+        Path to saved pipeline notebook.
+
+        See also
+        --------
+        RemoteAutoPipelines.summary()
+
+        Example
+        -------
+        >>> from ibm_watson_machine_learning.experiment import AutoAI
+        >>> experiment = AutoAI(credentials, ...)
+        >>> remote_optimizer = experiment.optimizer(...)
+        >>>
+        >>> pipeline_notebook_path = remote_optimizer.get_pipeline_notebook(pipeline_name='Pipeline_1')
+
+        """
+        if pipeline_name is None:
+            pipeline_name = self._engine.summary().index[0]
+
+        path = self._engine.get_pipeline_notebook(pipeline_name, filename=filename)
+
+        if insert_to_cell:
+            with open(path, 'r') as f:
+                content = json.loads(f.read())
+
+            def translate_cell_to_str(cell):
+                if cell['cell_type'] == 'code':
+                    return ''.join(cell['source'])
+                elif cell['cell_type'] == 'markdown':
+                    return '\n'.join(["# " + l for l in ''.join(cell['source']).split('\n')])
+                else:
+                    return ''
+
+            result = '\n\n'.join([translate_cell_to_str(c) for c in content['cells']])
+
+            import sys
+
+            def get_optimizer_var_name():
+                for name, module in sys.modules.items():
+                    for varname, obj in module.__dict__.items():
+                        if obj is self:
+                            return varname
+
+            if '\'PUT_YOUR_APIKEY_HERE\'' in result:
+                try:
+                    optimizer_var_name = get_optimizer_var_name()
+                    result = result.replace('\'PUT_YOUR_APIKEY_HERE\'', f'{optimizer_var_name}._workspace.wml_credentials[\'apikey\']')
+
+                except:
+                    pass
+
+            import IPython.core
+            ipython = IPython.core.getipython.get_ipython()
+            comment = "# generated by get_pipeline_notebook(insert_to_cell=True) from previous cell\n\n"
+            ipython.set_next_input(comment + result, replace=False)
+
+        return path
+
     # note: predict on top of the best computed pipeline, best pipeline is downloaded for the first time
     def predict(self, X: Union['DataFrame', 'ndarray']=None, observations: Union['DataFrame', 'ndarray']=None,
                 supporting_features: Union['DataFrame', 'ndarray']=None) -> 'ndarray':
