@@ -26,6 +26,7 @@ from ibm_watson_machine_learning.experiment.autoai.optimizers import RemoteAutoP
 from ibm_watson_machine_learning.preprocessing import DataJoinGraph
 from ibm_watson_machine_learning.utils.autoai.utils import NextRunDetailsGenerator, get_node_and_runtime_index
 from ibm_watson_machine_learning.helpers import DataConnection, S3Location, AssetLocation
+from ibm_watson_machine_learning.utils.autoai.enums import ForecastingPipelineTypes
 from .base_auto_pipelines_runs import BaseAutoPipelinesRuns
 from ibm_watson_machine_learning.wml_client_error import ApiRequestFailure
 
@@ -247,6 +248,18 @@ class AutoPipelinesRuns(BaseAutoPipelinesRuns):
             encoding = optimizer_config['entity']['document']['pipelines'][0]['nodes'][ts_node_number][
                 'parameters'].get('encoding', 'utf-8')
 
+            if ts_parameters.get('pipeline_type') == 'customized':
+                pipeline_types = ts_parameters.get('customized_pipelines')
+                pipeline_types = [ForecastingPipelineTypes(p) for p in pipeline_types]
+            elif ts_parameters.get('pipeline_type') == 'exogenous':
+                pipeline_types = ForecastingPipelineTypes.get_exogenous()
+            elif ts_parameters.get('pipeline_type') == 'non_exogenous':
+                pipeline_types = ForecastingPipelineTypes.get_non_exogenous()
+            elif ts_parameters.get('pipeline_type') == 'all':
+                pipeline_types = [l for l in ForecastingPipelineTypes]
+            else:
+                pipeline_types = None
+
             params = {
                 'name': name,
                 'desc': description,
@@ -254,8 +267,8 @@ class AutoPipelinesRuns(BaseAutoPipelinesRuns):
                 'prediction_column': ts_parameters.get('label'),
                 'prediction_columns': ts_parameters.get('target_columns'),
                 'timestamp_column_name': ts_parameters.get('timestamp_column'),
-                'holdout_size': ts_parameters['holdout_param'],
-                'max_num_daub_ensembles': ts_parameters['max_num_daub_ensembles'],
+                'holdout_size': ts_parameters.get('holdout_param', 20),
+                'max_num_daub_ensembles': ts_parameters.get('max_num_daub_ensembles', 3),
                 'backtest_gap_length': ts_parameters.get('gap_len'),
                 'backtest_num': ts_parameters.get('num_backtest'),
                 'forecast_window': ts_parameters.get('prediction_horizon'),
@@ -264,6 +277,10 @@ class AutoPipelinesRuns(BaseAutoPipelinesRuns):
                 't_shirt_size': ts_wml_data['hardware_spec']['id'],
                 'csv_separator': csv_separator,
                 'encoding': encoding,
+                'feature_columns': ts_parameters.get('feature_columns'),
+                'supporting_features_at_forecast': ts_parameters.get('future_exogenous_available'),
+                'pipeline_types': pipeline_types,
+                'retrain_on_holdout': ts_parameters.get('feature_columns', True),
             }
 
         else:
