@@ -224,7 +224,7 @@ class BaseDataConnection(ABC):
             # fast return true if the connection is an instance of S3Connection and non s3 type, or its attribute
             # "cos_type" takes True
             from .connections import S3Connection
-            if (isinstance(self.connection, S3Connection) and self.type != 's3') or (
+            if (isinstance(self.connection, S3Connection) and self.type != 's3' and self.connection.to_dict()) or (
                     self.connection is not None and getattr(self.connection, 'cos_type', False)):
                 return True
 
