@@ -1025,6 +1025,13 @@ class DataConnection(BaseDataConnection):
                     else:
                         raise TypeError("data should be either of type \"str\" or \"pandas.DataFrame\"")
 
+            if getattr(self._wml_client, '_internal', False):
+                pass  # don't remove additional params if client is used internally
+            else:
+                # note: remove additional params and inline credentials added by _check_if_connection_asset_is_s3:
+                [delattr(self.connection, attr) for attr in ['secret_access_key', 'access_key_id', 'endpoint_url', 'cos_type'] if
+                    hasattr(self.connection, attr)]
+                # end note
         elif self.type == DataConnectionTypes.DS:
             if self._wml_client is not None and not self._wml_client.ICP and not use_flight:  # CLOUD
                 raise ConnectionError("Write of data for Data Asset is not supported on Cloud.")
