@@ -205,11 +205,11 @@ class ServiceInstanceNewPlan:
             if self._client.ICP:
                 if self._get_expiration_datetime():
                     if self._get_expiration_datetime() - timedelta(minutes=50) < datetime.now():
-                        return self._get_cpd_token_from_request()
-                    else:
-                        return self._client.wml_token
+                        self._client.wml_token = self._get_cpd_token_from_request()
+                        self._client.repository._refresh_repo_client()
                 else:
-                    return self._get_cpd_token_from_request()
+                    self._client.wml_token = self._get_cpd_token_from_request()
+                    self._client.repository._refresh_repo_client()
             elif self._client._is_IAM():
                 if self._get_expiration_datetime() - timedelta(minutes=15) < datetime.now():
                     self._client.wml_token = self._get_IAM_token()
