@@ -14,8 +14,10 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+import requests as req
 import os
 import sys
+import ssl
 import importlib.util
 from pathlib import Path
 import platform
@@ -37,6 +39,8 @@ def process_heartbeat(client, **kwargs):
         hearbeat_resp_json = json.loads(hearbeat_resp.content.decode("utf-8"))
         service_version = hearbeat_resp_json.get("service_implementation")
 
+        if service_version.startswith("4.5") or service_version.startswith("45") or service_version.startswith("0.1.10000"):
+            return "cpd450"
         if service_version.startswith("4.0"):
             version_details = service_version.split('-')
             if version_details[1] >= "202203":
@@ -71,7 +75,7 @@ def import_diff(module_file_path):
         # because path is object not string
         path_in_str = str(path)
         if not path_in_str.endswith("__init__.py"):
-            module_name = ("ibmfl" + path_in_str.split("ibmfl")[2].replace("/", "."))[:-3]
+            module_name = ("ibmfl" + path_in_str.split("ibmfl")[2].replace(os.sep, "."))[:-3]
             module_spec = importlib.util.spec_from_file_location(
                 module_name, path_in_str)
             loader = importlib.util.LazyLoader(module_spec.loader)
@@ -90,7 +94,7 @@ def choose_software_version(software_spec):
 
 def check_python_version(platform_env):
     py_version = platform.python_version()
-    if platform_env != "cloud" and platform_env != "cpd407" and platform_env != "cpd408":
+    if platform_env != "cloud" and platform_env != "cpd407" and platform_env != "cpd408" and platform_env != "cpd450":
         if not py_version.startswith("3.7.") and not py_version.startswith("3.8."):
             raise Exception("Python version {} is not supported for Federated Learning. "
                             "Parties must use a supported Python version to train the model. "
@@ -123,6 +127,7 @@ class Party(WMLResource):
         'cpd406': "/cpd406/ibmfl",
         'cpd407': "/cpd406/ibmfl",
         'cpd408': "/cpd406/ibmfl",
+        'cpd450': "/cpd406/ibmfl",
         'py38-tf24-pt17-sk23': "/py38-tf24-pt17-sk23/ibmfl", #default
         'py39-tf27-pt110-sk10': "/py39-tf27-pt110-sk10/ibmfl"
     }
@@ -138,6 +143,7 @@ class Party(WMLResource):
         # get arg for platform
         calculated_platform_env = process_heartbeat(client=client, **kwargs)
         platform_env = kwargs.get('env', calculated_platform_env)
+        print("Detected platform environment: {}".format(platform_env))
 
         #check python version
         check_python_version(platform_env)
@@ -257,10 +263,21 @@ class Party(WMLResource):
         }
         if 'metrics_recorder' not in config_dict:
             config_dict["metrics_recorder"] = metrics_config
-        agg_info = config_dict.get('aggregator').get('ip').split('/')[0] + "/ml/v4/trainings/" + aggregator_id
+        wml_services_url = config_dict.get('aggregator').get('ip').split('/')[0]
+        agg_info = wml_services_url + "/ml/v4/trainings/" + aggregator_id
         config_dict['aggregator']['ip'] = agg_info
         self.args['config_dict'] = config_dict
 
+        #verify ssl context
+        if verify:
+            try:
+                req.get("https://" + wml_services_url + "/wml_services/training/heartbeat", verify=verify)
+            except requests.exceptions.SSLError as ex:
+                logger.error(str(ex))
+                raise FLException("No valid certificate detected. Please replace the default certificate with your own "
+                                  "TLS certificate, or set verify to False at your own risk. For more details, please see "
+                                  "https://www.ibm.com/docs/en/cloud-paks/cp-data/4.0?topic=client-using-custom-tls-certificate-connect-platform")
+
         #check for aggregator state and start job
         try:
             training_status = self._client.training.get_status(aggregator_id)
@@ -287,7 +304,7 @@ class Party(WMLResource):
                     if "software_spec" in fl_entity:
                         software_spec = fl_entity["software_spec"]["name"] if "name" in fl_entity["software_spec"] else fl_entity["software_spec"]["id"]
                     else:
-                        software_spec = "default_py3.8"
+                        software_spec = "runtime-22.1-py3.9"
                     platform_env = choose_software_version(software_spec)
                     print("Loading {} environment..".format(platform_env))
                     self.module_location = '/'.join(self.module_location.split('/')[0:-2]) + self.SUPPORTED_PLATFORMS_MAP.get(platform_env)
