@@ -353,6 +353,50 @@ class Training(WMLResource):
          >>> }
          >>> training_details = client.training.run(definition_uid, meta_props=metadata)
          >>> training_uid = client.training.get_id(training_details)
+
+         Example of a Federated Learning training job
+         >>> aggregator_metadata = {
+         >>>       wml_client.training.ConfigurationMetaNames.NAME: 'Federated_Learning_Tensorflow_MNIST',
+         >>>       wml_client.training.ConfigurationMetaNames.DESCRIPTION: 'MNIST digit recognition with Federated Learning using Tensorflow',
+         >>>       wml_client.training.ConfigurationMetaNames.TRAINING_DATA_REFERENCES: [],
+         >>>       wml_client.training.ConfigurationMetaNames.TRAINING_RESULTS_REFERENCE: {
+         >>>           'type': results_type,
+         >>>           'name': 'outputData',
+         >>>           'connection': {},
+         >>>           'location': {
+         >>>              'path': '/projects/' + PROJECT_ID + '/assets/trainings/'
+         >>>           }
+         >>> 
+         >>>       },
+         >>>       wml_client.training.ConfigurationMetaNames.FEDERATED_LEARNING: {
+         >>>           'model': {
+         >>>               'type': 'tensorflow',
+         >>>               'spec': {
+         >>>                  'id': untrained_model_id
+         >>>               },
+         >>>               'model_file': untrained_model_name
+         >>>           },
+         >>>           'fusion_type': 'iter_avg',
+         >>>           'metrics': 'accuracy',
+         >>>           'epochs': 3,
+         >>>           'rounds': 10,
+         >>>           'remote_training' : {
+         >>>               'quorum': 1.0,
+         >>>               'max_timeout': 3600,
+         >>>               'remote_training_systems': [ { 'id': prime_rts_id }, { 'id': nonprime_rts_id} ]
+         >>>           },
+         >>>           'hardware_spec': {
+         >>>               'name': 'S'
+         >>>           },
+         >>>           'software_spec': {
+         >>>               'name': 'runtime-22.1-py3.9'
+         >>>           }
+         >>>       }
+         >>>   }
+         >>>   
+         >>> 
+         >>> aggregator = wml_client.training.run(aggregator_metadata, asynchronous=True)
+         >>> aggregator_id = wml_client.training.get_id(aggregator)
         """
 
         WMLResource._chk_and_block_create_update_for_python36(self)
