@@ -59,7 +59,8 @@ __all__ = [
     'InconsistentImputationListElements',
     'ImputationListNotSupported',
     'MissingEstimatorForExistingBatchedEstimator',
-    'FutureExogenousFeaturesNotSupported'
+    'FutureExogenousFeaturesNotSupported',
+    'NoAvailableNotebookLocation'
 ]
 
 #  (C) Copyright IBM Corp. 2021.
@@ -421,4 +422,11 @@ class MissingEstimatorForExistingBatchedEstimator(WMLClientError, ValueError):
 class FutureExogenousFeaturesNotSupported(WMLClientError, ValueError):
     def __init__(self, prediction_type: str):
         WMLClientError.__init__(self, f"Future Exogenous features are only supported for forecasting."
-                                      f"Current prediction type is: {prediction_type}")
\ No newline at end of file
+                                      f"Current prediction type is: {prediction_type}")
+
+
+class NoAvailableNotebookLocation(WMLClientError, ValueError):
+    def __init__(self, pipeline_name):
+        WMLClientError.__init__(self, f"Unable to find notebook location in training details for {pipeline_name}. " +
+                                "Possible causes: pipeline failure or pipeline not classified as winner in " +
+                                "forecasting scenario.")
\ No newline at end of file
